@@ -1,7 +1,7 @@
 app <- ShinyDriver$new("../../")
 app$snapshotInit("priors_autoSetEmpty", screenshot = FALSE)
 
-app$setInputs(advOpts_cores = 4, wait_ = FALSE, values_ = FALSE)
+app$setInputs(advOpts_cores = 2, wait_ = FALSE, values_ = FALSE)
 
 app$setInputs(navbar_ID = "Data",
               ex_da_sel = "bacteria")
@@ -9,7 +9,7 @@ app$setInputs(navbar_ID = "Likelihood",
               outc_sel = "y",
               dist_sel = "bernoulli")
 app$setInputs(likelihood_navlist_ID = "Predictors",
-              pred_mainNP_sel = "week",
+              pred_mainCP_sel = "week",
               pred_mainPP_sel = "ID")
 app$setInputs(pred_int_build = c("week", "ID"),
               pred_int_add = "click")
